# Define your item pipelines here
#
# Don't forget to add your pipeline to the ITEM_PIPELINES setting
# See: https://docs.scrapy.org/en/latest/topics/item-pipeline.html


# useful for handling different item types with a single interface


from em_product.resources.pipelines import (
    ESCategoryPipeline,
    ESProductUrlPipeline,
    ESProductPipeline,
    ESProductRecrawlPipeline,
    ESTranslationPipeline,
)


class CategoryPipeline(ESCategoryPipeline):
    CATEGORY_INDEX = "rakuten_categories_v2"
    ELASTICSEARCH_INDEX = CATEGORY_INDEX


class ProductUrlPipeline(ESProductUrlPipeline):
    CATEGORY_INDEX = "rakuten_categories_v2"
    PRODUCT_URL_INDEX = "rakuten_product_urls_v2"
    ELASTICSEARCH_INDEX = PRODUCT_URL_INDEX


class ProductPipeline(ESProductPipeline):
    PRODUCT_URL_INDEX = "rakuten_product_urls_v2"
    PRODUCT_INDEX = "rakuten_products_v2"
    ELASTICSEARCH_INDEX = PRODUCT_INDEX
    FORCE = True

    def open_spider(self, spider):
        if not self.ELASTICSEARCH_INDEX:
            raise Exception("Please provide es index")

        self.ensure_indice(self.ELASTICSEARCH_INDEX)


class ProductRecrawlPipeline(ESProductRecrawlPipeline):
    PRODUCT_INDEX = "rakuten_products_v2"
    ELASTICSEARCH_INDEX = PRODUCT_INDEX

    def open_spider(self, spider):
        for doc in self.load_products():
            if doc.get("url"):
                spider.start_urls.append(doc["url"])
            elif doc.get("product_url"):
                spider.start_urls.append(doc["product_url"])
            else:
                pass
                # raise ValueError("No Url")


class TranslationPipeline(ESTranslationPipeline):
    TRANSLATION_INDEX = "rakuten_translation"
    ELASTICSEARCH_BUFFER_LENGTH = 100
    # ELASTICSEARCH_BUFFER_LENGTH = 1000
    ELASTICSEARCH_INDEX = TRANSLATION_INDEX
