import logging
import json

from peewee import *

from em_product.product import StandardProduct


from utils.site_product import fetch_source_ids
from utils.price_calculator import PriceCalculator

from em_product.utils.formatter import to_upload
from em_product.resources.filters import product_filer, doc_filer

from .loader import RakutenElasticSearchLoder, TranslationElasticSearchLoder

from rakuten.settings import (
    ELASTICSEARCH_SERVERS,
    ELASTICSEARCH_USERNAME,
    ELASTICSEARCH_PASSWORD,
)

from rakuten.product_manager.formatter import remove_invalid_specifications

def add_translated_title(product, loader):
    translation = loader.search_content([str(product["product_id"])], "translation")
    if translation:
        product["title_en"] = translation[str(product["product_id"])].pop()["title_en"]
        return None

def main():
    product_ids = fetch_source_ids(["Rakuten"])
    price_rules = {"roi": 0.3, "ad_cost": 3, "transfer_cost": 13}

    price_calculator = PriceCalculator(price_rules)
    filterd_settings = {
        "ELASTICSEARCH_SERVERS": ELASTICSEARCH_SERVERS,
        "ELASTICSEARCH_USERNAME": ELASTICSEARCH_USERNAME,
        "ELASTICSEARCH_PASSWORD": ELASTICSEARCH_PASSWORD,
    }

    loader = RakutenElasticSearchLoder(filterd_settings, "product_id")
    translation_loader = TranslationElasticSearchLoder(filterd_settings, "id")

    with open("rakuten_upload_092001.txt", "w+") as file:
        for doc in loader.load_content(type="product", query=None):
            try:
                if doc_filer(doc):
                    continue

                product = doc
                if doc["product_id"] in product_ids:
                    continue

                product = add_translated_title(doc, translation_loader)
                if not product:
                    continue

                product["specifications"] = remove_invalid_specifications(product["specifications"])
                product["upc"] = str(product["upc"])


                standard_product = StandardProduct(**product)
                formated_product = to_upload(standard_product.model_dump(), price_calculator)
                if product_filer(product):
                    continue

                json.dump(formated_product, file, ensure_ascii=False)
                file.write("\n")
            except Exception as e:
                logging.error(e)


if __name__ == "__main__":
    main()
