from rakuten.pipelines import ProductPipeline
from rakuten.spiders.product import ProductSpider
from scrapy.utils.project import get_project_settings
from scrapy.utils.test import get_crawler

from .loader import RakutenElasticSearchLoder

from .formatter import to_upload, to_standard
from urllib.parse import urlparse

from rakuten.settings import (
    ELASTICSEARCH_SERVERS,
    ELASTICSEARCH_USERNAME,
    ELASTICSEARCH_PASSWORD,
)


def get_product_url_path(url):
    if not url:
        return None

    parsed_url = urlparse(url)
    return parsed_url.path


def get_product_id(doc):
    # return doc.get("_id") or get_product_url_path(doc.get("product_url"))
    return get_product_url_path(doc.get("product_url"))


def filter_products(products, loader):
    results = loader.search_products(list(products.keys()))
    if not results:
        return products

    for key, value in results.items():
        products.pop(key)

    return products


def main():
    filterd_settings = {
        "ELASTICSEARCH_SERVERS": ELASTICSEARCH_SERVERS,
        "ELASTICSEARCH_USERNAME": ELASTICSEARCH_USERNAME,
        "ELASTICSEARCH_PASSWORD": ELASTICSEARCH_PASSWORD,
    }

    loader = RakutenElasticSearchLoder(filterd_settings, "product_id")

    settings = get_project_settings()
    crawler = get_crawler(ProductSpider)
    product_pipeline = ProductPipeline(settings)
    spider = crawler._create_spider()
    # translation_pipeline.open_spider(spider)

    batch_size = 1000
    products = {}
    for doc in loader.load_content(type="product", query=None):
        try:
            if not doc.get("specifications") or doc.get("specifications") == "specifications":
                continue

            doc.pop("_id")
            products[get_product_id(doc)] = doc
            if len(products) < batch_size:
                continue

            to_uploads = filter_products(products, loader)
            for _, product in to_uploads.items():
                product_pipeline.process_item(product, spider)
            products = {}
        except Exception as e:
            breakpoint()

    if products:
        to_uploads = filter_products(products, loader)
        for _, product in to_uploads:
            product_pipeline.process_item(product, spider)
        products = {}
    product_pipeline.close_spider(spider)


if __name__ == "__main__":
    main()
