from rakuten.pipelines import TranslationPipeline
from rakuten.spiders.product import ProductSpider
from scrapy.utils.project import get_project_settings
from scrapy.utils.test import get_crawler

from .loader import RakutenElasticSearchLoder

from urllib.parse import urlparse

from rakuten.settings import (
    ELASTICSEARCH_SERVERS,
    ELASTICSEARCH_USERNAME,
    ELASTICSEARCH_PASSWORD,
)


def get_product_id_from_url(url):
    parsed_url = urlparse(url)
    return parsed_url.path.split("/").pop()


def main():
    filterd_settings = {
        "ELASTICSEARCH_SERVERS": ELASTICSEARCH_SERVERS,
        "ELASTICSEARCH_USERNAME": ELASTICSEARCH_USERNAME,
        "ELASTICSEARCH_PASSWORD": ELASTICSEARCH_PASSWORD,
    }

    loader = RakutenElasticSearchLoder(filterd_settings, "product_id")

    settings = get_project_settings()
    crawler = get_crawler(ProductSpider)
    translation_pipeline = TranslationPipeline(settings)
    spider = crawler._create_spider()
    # translation_pipeline.open_spider(spider)

    for doc in loader.load_content(type="product", query=None):
        try:
            if not doc.get("title_en"):
                continue

            translation = {
                "id": doc["_id"],
                "title": doc["title"],
                "title_en": doc["title_en"],
            }

            translation_pipeline.process_item(translation, spider)
        except Exception as e:
            pass

    translation_pipeline.close_spider(spider)


if __name__ == "__main__":
    main()
