from datetime import datetime
import json
from multiprocessing.pool import ThreadPool
import re

from em_product.product import ProductSource
from google.oauth2 import service_account
from google.cloud.translate_v2 import Client
from pymongo import MongoClient
from urllib.parse import urlparse


from rakuten.settings import MONGO_URI
from utils.translate_service import get_translator


def connect_to_mongo_by_collection(db_name, collection_name):
    client = MongoClient(MONGO_URI)
    db = client[db_name]
    collection = db[collection_name]
    return collection


def translate_product(collection, product, title_translator):
    if product.get("title_en"):
        return

    translation = title_translator(product["title"])
    if not translation:
        return

    try:
        collection.update_one(
            {"_id": product["_id"]},
            {
                "$set": {
                    "title_en": translation,
                }
            },
        )
    except Exception as e:
        print(f"{e}")
        pass


def main():
    service_account_path = "./gc.json"
    target_language = "en"
    translation_service = Client(
        target_language=target_language,
        credentials=service_account.Credentials.from_service_account_file(service_account_path),
    )
    db_name = "rakuten"
    collection_name = "products"
    collection = connect_to_mongo_by_collection(db_name, collection_name)

    pool = ThreadPool(10)
    query = {
        "title": {"$exists": True},
        "title_en": {"$exists": False},
        "price": {"$exists": True, "$ne": ""},
        "has_only_default_variant": True,
    }

    total_count = collection.count_documents(query)
    supported_languages = ["ja"]
    title_translator = get_translator(translation_service, total_count, supported_languages)

    for doc in collection.find(query):
        # translate_product(collection, doc, title_translator)
        pool.apply_async(translate_product, args=(collection, doc, title_translator))
    pool.close()
    pool.join()


if __name__ == "__main__":
    main()
